=====
GISMO
=====


.. image:: https://img.shields.io/pypi/v/gismo.svg
        :target: https://pypi.python.org/pypi/gismo

.. image:: https://img.shields.io/travis/balouf/gismo.svg
        :target: https://travis-ci.org/balouf/gismo

.. image:: https://readthedocs.org/projects/gismo/badge/?version=latest
        :target: https://gismo.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://codecov.io/gh/balouf/gismo/branch/master/graphs/badge.svg
        :target: https://codecov.io/gh/balouf/gismo/branch/master/graphs/badge
        :alt: Code Coverage





GISMO is a NLP tool to rank and organize a corpus of documents according to a query.


* Free software: GNU General Public License v3
* Documentation: https://gismo.readthedocs.io.


Features
--------

* TF-IDTF

Credits
-------

This package was created with Cookiecutter_ and the `francois-durand/package_helper`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`francois-durand/package_helper`: https://github.com/francois-durand/package_helper
